@@ -6,10 +6,16 @@ const fs = require('fs');
 const path = require('path');
 const crypto = require('crypto');
 
-// Read MySQL configuration from PHP config file
-const phpConfig = fs.readFileSync('/docker/whp/web/configs/config.php', 'utf8');
-// Look for $root_mysql_password = 'password'; pattern
-const mysqlPass = phpConfig.match(/\$root_mysql_password\s*=\s*'([^']+)'/)?.[1] || '';
+// Read MySQL password from /root/.my.cnf (same as PHP config does)
+const { execSync } = require('child_process');
+let mysqlPass = '';
+try {
+    // Execute the same command as PHP: cat /root/.my.cnf |grep password |cut -f2- -d=
+    mysqlPass = execSync('cat /root/.my.cnf | grep password | cut -f2- -d=', { encoding: 'utf8' }).trim();
+} catch (error) {
+    console.error('Failed to read MySQL password from /root/.my.cnf:', error.message);
+    process.exit(1);
+}
 
 // Configuration
 const CONFIG = {
